'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var semanticUiReact = require('semantic-ui-react');
var React = require('react');
var React__default = _interopDefault(React);
var cx = _interopDefault(require('classnames'));
var reactRouterDom = require('react-router-dom');
require('redux-react-hook');
require('redux');
require('redux-saga');
require('redux-saga/effects');
var typesafeActions = require('typesafe-actions');
var lodashEs = require('lodash-es');
require('node-fetch');
require('@hiro-graph/orm');
require('@hiro-graph/orm-mappings');

const renderLogo = logo => React__default.createElement(semanticUiReact.Image, {
  size: "mini",
  src: logo,
  spaced: "right",
  alt: "logo"
});

const renderNav = (navigation, location) => {
  const className = n => cx("link", "item", {
    active: n.href === location.pathname
  });

  return navigation.map(n => React__default.createElement(reactRouterDom.Link, {
    to: n.href,
    key: n.href,
    className: className(n)
  }, n.contents));
};

const renderSearch = ({
  options,
  onChange
}) => React__default.createElement(semanticUiReact.Menu.Item, null, React__default.createElement(semanticUiReact.Dropdown, {
  placeholder: "State",
  search: true,
  selection: true,
  options: options,
  onChange: onChange
}));

const renderDropDown = ({
  options,
  trigger,
  color = "black"
}) => React__default.createElement(semanticUiReact.Dropdown, {
  item: true,
  options: options,
  trigger: trigger,
  icon: React__default.createElement(semanticUiReact.Icon, {
    name: "caret down",
    size: "large",
    color: color
  })
});

const TopBar = reactRouterDom.withRouter(({
  navigation,
  logo,
  title,
  search,
  dropdown,
  location
}) => {
  const showMenu = search || dropdown;
  let menu;

  if (showMenu) {
    menu = React__default.createElement(semanticUiReact.Menu.Menu, {
      position: "right"
    }, search && renderSearch(search), dropdown && renderDropDown(dropdown));
  }

  return React__default.createElement(semanticUiReact.Menu, null, React__default.createElement(semanticUiReact.Container, {
    fluid: true
  }, React__default.createElement(semanticUiReact.Menu.Item, {
    header: true
  }, React__default.createElement("span", null, logo && renderLogo(logo), title)), navigation && renderNav(navigation, location), menu));
});

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    var ownKeys = Object.keys(source);

    if (typeof Object.getOwnPropertySymbols === 'function') {
      ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
      }));
    }

    ownKeys.forEach(function (key) {
      _defineProperty(target, key, source[key]);
    });
  }

  return target;
}

const errorSet = typesafeActions.createStandardAction("ERROR_SET")();
const errorClear = typesafeActions.createStandardAction("ERROR_CLEAR")();

const errorReducer = typesafeActions.createReducer(null).handleAction("ERROR_SET", (_, {
  payload: {
    name = "Error",
    message
  }
}) => ({
  name,
  message
})).handleAction("ERROR_CLEAR", () => null);

const themeRequest = typesafeActions.createStandardAction("THEME_REQUEST")();
const themeSuccess = typesafeActions.createStandardAction("THEME_SUCCESS")();
const themeError = typesafeActions.createStandardAction("THEME_ERROR")();

const themeReducer = typesafeActions.createReducer({}).handleAction("THEME_REQUEST", (_, {
  payload: {
    theme = "default",
    themeVersion = "latest"
  }
}) => ({
  theme,
  themeVersion
})).handleAction("THEME_SUCCESS", (state, {
  payload
}) => _objectSpread({}, state, payload)).handleAction("THEME_ERROR", (state, {
  payload
}) => _objectSpread({}, state, payload));

const tokenSet = typesafeActions.createStandardAction("TOKEN_SET")();
const tokenClear = typesafeActions.createStandardAction("TOKEN_CLEAR")();

const authReducer = typesafeActions.createReducer({}).handleAction("TOKEN_SET", (state, {
  payload
}) => _objectSpread({}, state, {
  token: payload.token
})).handleAction("TOKEN_CLEAR", state => _objectSpread({}, lodashEs.omit(state, ["token"])));

const HiroAuthContext = React.createContext({});

Object.keys(semanticUiReact).forEach(function (key) {
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return semanticUiReact[key];
    }
  });
});
Object.defineProperty(exports, 'ERROR_NAMESPACE', {
  enumerable: true,
  get: function () {
    return semanticUiReact.ERROR_NAMESPACE;
  }
});
Object.defineProperty(exports, 'HiroApp', {
  enumerable: true,
  get: function () {
    return semanticUiReact.HiroApp;
  }
});
Object.defineProperty(exports, 'HiroStyle', {
  enumerable: true,
  get: function () {
    return semanticUiReact.HiroStyle;
  }
});
Object.defineProperty(exports, 'THEME_NAMESPACE', {
  enumerable: true,
  get: function () {
    return semanticUiReact.THEME_NAMESPACE;
  }
});
Object.defineProperty(exports, 'TopBar', {
  enumerable: true,
  get: function () {
    return semanticUiReact.TopBar;
  }
});
Object.defineProperty(exports, 'errorClear', {
  enumerable: true,
  get: function () {
    return semanticUiReact.errorClear;
  }
});
Object.defineProperty(exports, 'errorReducer', {
  enumerable: true,
  get: function () {
    return semanticUiReact.errorReducer;
  }
});
Object.defineProperty(exports, 'errorSet', {
  enumerable: true,
  get: function () {
    return semanticUiReact.errorSet;
  }
});
Object.defineProperty(exports, 'handleThemes', {
  enumerable: true,
  get: function () {
    return semanticUiReact.handleThemes;
  }
});
Object.defineProperty(exports, 'init', {
  enumerable: true,
  get: function () {
    return semanticUiReact.init;
  }
});
Object.defineProperty(exports, 'themeError', {
  enumerable: true,
  get: function () {
    return semanticUiReact.themeError;
  }
});
Object.defineProperty(exports, 'themeReducer', {
  enumerable: true,
  get: function () {
    return semanticUiReact.themeReducer;
  }
});
Object.defineProperty(exports, 'themeRequest', {
  enumerable: true,
  get: function () {
    return semanticUiReact.themeRequest;
  }
});
Object.defineProperty(exports, 'themeSuccess', {
  enumerable: true,
  get: function () {
    return semanticUiReact.themeSuccess;
  }
});
Object.defineProperty(exports, 'useColours', {
  enumerable: true,
  get: function () {
    return semanticUiReact.useColours;
  }
});
Object.defineProperty(exports, 'useErrorDispatch', {
  enumerable: true,
  get: function () {
    return semanticUiReact.useErrorDispatch;
  }
});
Object.defineProperty(exports, 'useErrorState', {
  enumerable: true,
  get: function () {
    return semanticUiReact.useErrorState;
  }
});
Object.defineProperty(exports, 'useThemeDispatch', {
  enumerable: true,
  get: function () {
    return semanticUiReact.useThemeDispatch;
  }
});
Object.defineProperty(exports, 'useThemeState', {
  enumerable: true,
  get: function () {
    return semanticUiReact.useThemeState;
  }
});
