import React, { useCallback, useState } from "react";
import { BrowserRouter } from "react-router-dom";
import { Container, Loader } from "semantic-ui-react";
import { StoreContext } from "redux-react-hook";
import { init } from "../stores/index.js";
import { ErrorBar } from "./ErrorBar.js";
import { HiroStyle } from "./HiroStyle.js";
import { HiroAuth } from "./HiroAuth.js";
export const HiroApp = ({
  children,
  ready,
  theme,
  themeVersion,
  fluid,
  store,
  auth
}) => {
  const [loading, setLoading] = useState(true);
  let rootStore = store;

  if (!rootStore) {
    rootStore = init();
  }

  const setReady = useCallback(() => {
    if (ready) {
      ready();
    }

    setLoading(false);
  }, [ready]);
  const content = loading ? React.createElement(Loader, {
    active: true,
    size: "huge",
    content: "Loading..."
  }) : children;
  return React.createElement(BrowserRouter, null, React.createElement(StoreContext.Provider, {
    value: rootStore
  }, React.createElement(HiroStyle, {
    theme: theme,
    themeVersion: themeVersion,
    onLoad: setReady
  }), React.createElement(Container, {
    fluid: fluid
  }, auth ? React.createElement(HiroAuth, {
    config: auth
  }, content) : content, React.createElement(ErrorBar, null))));
};